﻿using AutoMapper;
using BizService;
using Microsoft.Extensions.Logging;
using Model.Entities;
using PLCTool.Common;
using PLCTool.Models;
using Prism.Commands;
using Prism.Events;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace PLCTool.ViewModels.SystemManageViewModel.Dialogs
{
  
    public class RoleWithMenuViewModel : BindableBase, IDialogAware
    {
        private readonly IMapper _mapper;
        private readonly ILogger _logger;
        private readonly IRoleService _iRoleService;
        private readonly IMenuService _iMenuService;
        private readonly IRoleMenuService _iRoleMenuService;
        private string tyepName = String.Empty;
        private int roleId;

        public RoleWithMenuViewModel(IEventAggregator aggregator, IRoleService iRoleService,IMenuService iMenuService, IRoleMenuService iRoleMenuService,   IMapper mapper, ILogger logger)
        {

           
            _mapper = mapper;
            _logger = logger;
            _iMenuService = iMenuService;
            _iRoleMenuService = iRoleMenuService;
            _iRoleService = iRoleService;
            SureCommand = new DelegateCommand<string>(Sure);
         
            SelectAllCommand = new DelegateCommand<object>(SelectAll);
            UnSelectAllCommand = new DelegateCommand<object>(UnSelecttAll);
           
        }

        private void GetAllMenus()
        {
            var menus = _iMenuService.QueryList();
            foreach (var menu in menus)
            {
                //查找角色是否带有这个菜单
                bool isSelect = false;

                var findMenu= _iRoleMenuService.FindAllByRoleId(roleId).FirstOrDefault(x=>x.MenuId==menu.MenuId);
                if(findMenu != null)
                {
                    isSelect = true;
                }
                RoleWithMenuList.Add(new SelectRoleMenuDto
                {
                    MenuId=menu.MenuId,
                    MenuHeader = menu.MenuHeader,
                    Describe = menu.ParentId == 0 ? "一级菜单" : "二级菜单",
                    IsSelected = isSelect
                });
            }
        }

        private void UnSelecttAll(object obj)
        {
            RoleWithMenuList.ToList().FindAll(p => p.IsSelected = false);
        }

        private void SelectAll(object obj)
        {
            RoleWithMenuList.ToList().FindAll(p => p.IsSelected = true);
        }

        


        private void Sure(string obj)
        {
            //查找是否有这个测试方案

            var findSelect = RoleWithMenuList.FirstOrDefault(x => x.IsSelected == true);
            if (findSelect == null)
            {
                MessageBoxResult boxResult = MessageBox.Show("请勾选测试项！", "提示", MessageBoxButton.OK, MessageBoxImage.Warning);
                return;
            }
            //查找的信息
            //删除这个角色以前的菜单
            var findMenus = _iRoleMenuService.FindAllByRoleId(roleId);
            foreach(var item in  findMenus)
            {
                _iRoleMenuService.Delete(item.Id);
            }
            //添加角色关联的菜单到数据库
            var roleMeuns = RoleWithMenuList.ToList().FindAll(x => x.IsSelected).OrderBy(y => y.MenuId);
            foreach (var item in roleMeuns)
            {
                _iRoleMenuService.Add(new RoleMenu
                {
                    RoleId = roleId,
                    MenuId = item.MenuId
                });
            }
            RequestClose?.Invoke(new DialogResult(ButtonResult.OK));
        }

        public string Title { set; get; } = "授权角色菜单";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {

        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
           
            //设备类型
            var getMsg = parameters.GetValues<int>("Key");

            if (getMsg != null)
            {

                foreach (var item in getMsg)
                {

                    roleId = item;
                    GetAllMenus();
                    RoleName = _iRoleService.Find(roleId).Name;
                }
             

            }
       

        }
        #region 命令绑定
        public DelegateCommand<string> SureCommand { set; get; }


        public DelegateCommand<object> SelectAllCommand { set; get; }
        public DelegateCommand<object> UnSelectAllCommand { set; get; }

        #endregion
        #region 数据绑定
        /// <summary>
        /// 测试方案编码
        /// </summary>
        private string roleName;
        public string RoleName
        {
            get { return roleName; }
            set { roleName = value; RaisePropertyChanged(); }
        }
  


        private ObservableCollection<SelectRoleMenuDto> roleWithMenuList = new ObservableCollection<SelectRoleMenuDto>();
        public ObservableCollection<SelectRoleMenuDto> RoleWithMenuList
        {
            get { return roleWithMenuList; }
            set { SetProperty(ref roleWithMenuList, value); }
        }


        #endregion

    }
}
